Diagonal2

Struct Diagonal2 

pub struct Diagonal2 {
    pub xx: f64,
    pub yy: f64,
}
A diagonal matrix, suitable for representing anisotropic scaling.

Fields

xx: f64

The horizontal expansion factor.

yy: f64

The vertical expansion factor.

Implementations

Source

impl Diagonal2

pub const fn new(xx: f64, yy: f64) -> Self

Create a diagonal matrix.

pub const fn inv(self) -> Self

Matrix inverse.

Will of course produce infinities if a component is zero.

pub const fn abs(self) -> Self

Absolute value of transform components.

pub fn scale_normal(self, n: Vec2) -> Vec2

Scale a normal vector.

This is mathematically equivalent to self * (self * n).normalize() for positive transforms, but handles zeros and gets the sign correct when negative.

Note that n need not be unit length.